@@ -554,10 +554,18 @@ class ServerConnector(object):
             headers["User-Agent"] = self._ua_string
         logger.debug("Fetching URL {}\nwith headers {}".format(url, headers))
         timeout_sec = datetime_utils.to_sec(self._com.timeout_ms)
-        response = requests.get(url, headers=headers, timeout=timeout_sec, verify=False)
-        if response.status_code == requests.codes.not_acceptable:
-            response = requests.get(url, timeout=timeout_sec, verify=False)
-        return response
+        try:
+            response = requests.get(
+                url, headers=headers, timeout=timeout_sec, verify=False
+            )
+            if response.status_code == requests.codes.not_acceptable:
+                response = requests.get(url, timeout=timeout_sec, verify=False)
+            return response
+        except (requests.HTTPError, requests.ConnectionError):
+            response = Response()
+            response._content = b""
+            response.status_code = requests.codes.no_response
+            return response
 
     def render_status_by_id(self, *render_ids):
         # type: (*Text) -> List[RenderStatusResults]
